This function computes the Chumbley U-Statistic on systemically chosen pairs of windows rather than the original method which selects randomly chosen pairs of windows
chumbley_non_random(data1, data2, window_opt = 500, window_val = 50,
coarse = 0.25)The first tool mark as a 1-column matrix
The second tool mark as a 1-column matrix
size of the window to be used in the optimization step
Size of the window to be used in the validation step
smoothing parameter for the normalization smooth
list with
same_shift_n Number of same shift offsets used
diff_shift_n Number of different shift offsets used
U observed U statistic
p_value Corresponding p-value